@@ -33,7 +33,7 @@ def text_transform(value):
 class Wandbox:
     """wandbox api class"""
 
-    #api_url = 'http://melpon.org/wandbox/api'
+    # api_url = 'http://melpon.org/wandbox/api'
     api_url = 'https://wandbox.org/api'
     timeout_ = (3.0, 60.0 * 5)
 
@@ -72,6 +72,15 @@ class Wandbox:
         response.raise_for_status()
         return response.json()
 
+    @staticmethod
+    def GetTemplate(name):
+        """
+        get template
+        """
+        response = requests.get(Wandbox.api_url + '/template/' + name, timeout=3.0)
+        response.raise_for_status()
+        return response.json()
+
     @property
     def timeout(self):
         return self.timeout_
@@ -301,6 +310,7 @@ class Wandbox:
                     opt.append(s['name'])
         return opt
 
+
 if __name__ == '__main__':
     with Wandbox() as w:
         w.compiler('gcc-head')
